# -*- coding: utf-8 -*-

# Copyright (c) Pilot Systems, 2013

# This file is part of Faceted SeSQL.

# SeSQL is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.

# SeSQL is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with Faceted SeSQL.  If not, see <http://www.gnu.org/licenses/>.

"""
This is Faceted SeSQL simple benchmarking tool.
"""
import sys, time, random, string
from optparse import make_option

from django.core.management.base import BaseCommand
from django.core import serializers
from django.core.management import call_command

from pizza.models import *

def random_string(size):
    """
    Return a random string
    """
    letters = string.ascii_letters + string.digits
    value = ''.join([ random.choice(letters) for i in range(size) ])
    return value
    

class Command(BaseCommand):
    help = "Fill a database for bench purpose"

    option_list = BaseCommand.option_list + (
        make_option('-s', '--seed',
                    dest='seed',
                    type='int',
                    default=42,
                    help='Random seed (default 42)'),

        make_option('-p', '--pizza',
                    dest='pizza',
                    type='int',
                    default=100,
                    help='Number of pizza to create (default 100)'),

        )

    def handle(self, *apps, **options):
        """
        Handle the command
        """
        self.options = options
        random.seed(options['seed'])

        print "Creating DB and loading fixtures..."
        call_command('syncdb', verbosity = 0)
        call_command('loaddata', 'test', verbosity = 0)

        # Purge pizza
        Pizza.objects.all().delete()

        # Create pizza
        self.shops = list(Shop.objects.all())
        self.toppings = list(Topping.objects.all())
        print "Creating %d pizza..." % (self.options['pizza'])
        for i in range(self.options['pizza']):
            self.create_pizza()

    def chose_nb_top(self):
        """
        Chose number of toppings
        Algorithm is : make two random rolls, chose the lowest number
        unless the first roll is 1, in which case, use the second roll
        whatever
        """
        first = random.randint(1, len(self.toppings))
        second = random.randint(1, len(self.toppings))
        if first >= 2:
            return min(first, second)
        return second


    def create_pizza(self):
        """
        Create a pizza
        """
        p = Pizza()
        p.name = random_string(20)
        p.shop = random.choice(self.shops)
        p.persons = min(random.randint(1,4), random.randint(1,4))
        p.weight = random.randint(200,600) * p.persons
        p.calories = random.randint(300,800) * p.persons
        p.price = random.randint(5,20) * p.persons
        p.crust = random.choice([ ct[0] for ct in CRUST_TYPES ])
        nbtops = self.chose_nb_top()
        p.save()
        p.toppings = random.sample(self.toppings, nbtops)
        p.save()
